Learn R Programming

sybilDynFBA (version 0.0.2)

optsol_dynamicFBA-class: Class "optsol_dynamicFBA"

Description

Structure of the class "optsol_dynamicFBA". Objects of that class are returned by the function dynamicFBA. Extends the Class optsol_optimizeProb.

Arguments

Objects from the Class

Objects can be created by calls of the function optsol_dynamicFBA: test <- optsol_dynamicFBA(solver = "glpk", method = "simplex").

Extends

Class "optsol_optimizeProb", directly. Class "optsol", by class "optsol_optimizeProb", distance 2.

See Also

checkOptSol, optsol, optsol_optimizeProb

Examples

Run this code
showClass("optsol_dynamicFBA")

Run the code above in your browser using DataLab