Learn R Programming

sybilDynFBA (version 0.0.1)

sybilDynFBA-package: Dynamic Flux Balance Analysis

Description

The package sybilDynFBA implements dynamic flux balance anaylsis as proposed by Verma et al (1994). It uses functions from package sybil to find standard FBA solution. Solution can also be ploted.

Arguments

Details

ll{ Package: sybilDynFBA Type: Package Version: 0.0.1 Date: 2011-04-20 License: GPL Version 3 LazyLoad: yes Depends: sybil, methods }

References

Varma, A. and Palsson, B.O. 1994. Stoichiometric flux balance models quantitatively predict growth and metabolic by-product secretion in wild-type Escherichia coli W3110. Appl Environ Microbiol 60: 3724-3731.

See Also

sybil

Examples

Run this code
## The examples here require the package glpkAPI to be
	## installed. If that package is not available, you have to set
	## the argument 'solver' (the default is: solver = "glpk").

	## load the example data set
	data(Ec_core)
        lowbnd(Ec_core)[react_id(Ec_core)=='EX_glc(e)']=-10;
        lowbnd(Ec_core)[react_id(Ec_core)=='EX_o2(e)']=-18;
	## run dynamicFBA(), Ec_df will be an object of class \code{\link{optsol_dynamicFBA}}
	Ec_df <- dynamicFBA(Ec_core,substrateRxns={'EX_glc(e)'},initConcentrations=40,initBiomass=.035,timeStep=.25,nSteps=20,verbose=3)

	## plot biomass and reactions
	plot(Ec_df,plotRxns=c('EX_glc(e)','EX_ac(e)'));

Run the code above in your browser using DataLab